@@ -2,8 +2,8 @@
 import os
 
 # [[[fill git_describe()]]]
-__version__ = '2022.9.22+parent.222fc8ca'
-# [[[end]]] (checksum: 06eeb450e70dd9504d5a7b974122631e)
+__version__ = '2022.11.3+parent.b2476c33'
+# [[[end]]] (checksum: b4e4428e94fd528524b874c5451c9fd9)
 __version_info__ = tuple(
     e if '-' not in e else e.split('-')[0] for part in __version__.split('+') for e in part.split('.') if e != 'parent'
 )
@@ -12,6 +12,22 @@ APP_NAME = 'Calculate (Finnish: laskea) some parts.'
 APP_ALIAS = 'laskea'
 APP_ENV = 'LASKEA'
 CACHE_EXPIRY_SECONDS = int(os.getenv(f'{APP_ENV}_CACHE_EXPIRY_SECONDS', '180'))
+
+FIELD_SEPARATORS = (
+    CARET := '^',
+    COLON := ':',
+    COMMA := ',',
+    DASH := '-',
+    DOT := '.',
+    PIPE := '|',
+    PLUS := '+',
+    RS := '\x1e',
+    SEMI := ';',
+    SPACE := ' ',
+    TAB := '\t',
+    USCORE := '_',
+)
+
 DEBUG = bool(os.getenv(f'{APP_ENV}_DEBUG', ''))
 DRY_RUN = False
 VERBOSE = bool(os.getenv(f'{APP_ENV}_VERBOSE', ''))
@@ -78,6 +94,7 @@ from laskea.api.jira import (  # noqa
     markdown_table,
     parent_children_sections,
     query,
+    separated_values_list,
 )
 from laskea.embed import (  # noqa
     dl,
@@ -91,6 +108,7 @@ from laskea.embed import (  # noqa
     mbom_table,
     metrics_table,
     ol,
+    svl,
     table,
     test_plans,
     ul,
@@ -110,6 +128,7 @@ __all__ = [
     'markdown_list',
     'query',
     'ol',
+    'svl',
     'table',
     'ul',
     'kpi_table',
